diff mbox series

[net-next,v2,04/10] net: netconsole: rename body to msg_body

Message ID 20240909130756.2722126-5-leitao@debian.org (mailing list archive)
State Superseded
Delegated to: Netdev Maintainers
Headers show
Series netconsole refactoring and warning fix | expand

Checks

Context Check Description
netdev/series_format success Posting correctly formatted
netdev/tree_selection success Clearly marked for net-next
netdev/ynl success Generated files up to date; no warnings/errors; no diff in generated;
netdev/fixes_present success Fixes tag not required for -next series
netdev/header_inline success No static functions without inline keyword in header files
netdev/build_32bit fail Errors and warnings before: 16 this patch: 14
netdev/build_tools success No tools touched, skip
netdev/cc_maintainers success CCed 5 of 5 maintainers
netdev/build_clang fail Errors and warnings before: 16 this patch: 15
netdev/verify_signedoff success Signed-off-by tag matches author and committer
netdev/deprecated_api success None detected
netdev/check_selftest success No net selftest shell script
netdev/verify_fixes success No Fixes tag
netdev/build_allmodconfig_warn fail Errors and warnings before: 16 this patch: 14
netdev/checkpatch warning WARNING: line length of 81 exceeds 80 columns
netdev/build_clang_rust success No Rust files in patch. Skipping build
netdev/kdoc success Errors and warnings before: 0 this patch: 0
netdev/source_inline success Was 0 now: 0

Commit Message

Breno Leitao Sept. 9, 2024, 1:07 p.m. UTC
With the introduction of the userdata concept, the term body has become
ambiguous and less intuitive.

To improve clarity, body is renamed to msg_body, making it clear that
the body is not the only content following the header.

In an upcoming patch, the term body_len will also be revised for further
clarity.

The current packet structure is as follows:

	release, header, body, [msg_body + userdata]

Here, [msg_body + userdata] collectively forms what is currently
referred to as "body." This renaming helps to distinguish and better
understand each component of the packet.

Signed-off-by: Breno Leitao <leitao@debian.org>
Reviewed-by: Simon Horman <horms@kernel.org>
---
 drivers/net/netconsole.c | 48 +++++++++++++++++++++++-----------------
 1 file changed, 28 insertions(+), 20 deletions(-)

Comments

Simon Horman Sept. 9, 2024, 4:03 p.m. UTC | #1
On Mon, Sep 09, 2024 at 06:07:45AM -0700, Breno Leitao wrote:
> With the introduction of the userdata concept, the term body has become
> ambiguous and less intuitive.
> 
> To improve clarity, body is renamed to msg_body, making it clear that
> the body is not the only content following the header.
> 
> In an upcoming patch, the term body_len will also be revised for further
> clarity.
> 
> The current packet structure is as follows:
> 
> 	release, header, body, [msg_body + userdata]
> 
> Here, [msg_body + userdata] collectively forms what is currently
> referred to as "body." This renaming helps to distinguish and better
> understand each component of the packet.
> 
> Signed-off-by: Breno Leitao <leitao@debian.org>
> Reviewed-by: Simon Horman <horms@kernel.org>
> ---
>  drivers/net/netconsole.c | 48 +++++++++++++++++++++++-----------------
>  1 file changed, 28 insertions(+), 20 deletions(-)
> 
> diff --git a/drivers/net/netconsole.c b/drivers/net/netconsole.c
> index 8faea9422ea1..c312ad6d5cf8 100644
> --- a/drivers/net/netconsole.c
> +++ b/drivers/net/netconsole.c
> @@ -1092,22 +1092,22 @@ static void send_msg_fragmented(struct netconsole_target *nt,
>  {
>  	static char buf[MAX_PRINT_CHUNK]; /* protected by target_list_lock */
>  	int offset = 0, userdata_len = 0;
> -	const char *header, *body;
> -	int header_len, body_len;
> +	const char *header, *msgbody;
> +	int header_len, msgbody_len;
>  	const char *release;
>  
>  	if (userdata)
>  		userdata_len = nt->userdata_length;
>  
> -	/* need to insert extra header fields, detect header and body */
> +	/* need to insert extra header fields, detect header and msgbody */
>  	header = msg;
> -	body = memchr(msg, ';', msg_len);
> -	if (WARN_ON_ONCE(!body))
> +	msgbody = memchr(msg, ';', msg_len);
> +	if (WARN_ON_ONCE(!msgbody))
>  		return;
>  
> -	header_len = body - header;
> -	body_len = msg_len - header_len - 1;
> -	body++;
> +	header_len = msgbody - header;
> +	msgbody_len = msg_len - header_len - 1;
> +	msgbody++;
>  
>  	/*
>  	 * Transfer multiple chunks with the following extra header.
> @@ -1122,10 +1122,10 @@ static void send_msg_fragmented(struct netconsole_target *nt,
>  	memcpy(buf + release_len, header, header_len);
>  	header_len += release_len;
>  
> -	/* for now on, the header will be persisted, and the body
> +	/* for now on, the header will be persisted, and the msgbody
>  	 * will be replaced
>  	 */
> -	while (offset < body_len + userdata_len) {
> +	while (offset < msgbody_len + userdata_len) {
>  		int this_header = header_len;
>  		int this_offset = 0;
>  		int this_chunk = 0;
> @@ -1133,23 +1133,31 @@ static void send_msg_fragmented(struct netconsole_target *nt,
>  		this_header += scnprintf(buf + this_header,
>  					 sizeof(buf) - this_header,
>  					 ",ncfrag=%d/%d;", offset,
> -					 body_len + userdata_len);
> +					 msgbody_len + userdata_len);
>  
> -		/* Not all body data has been written yet */
> -		if (offset < body_len) {
> -			this_chunk = min(body_len - offset,
> +		/* Not all msgbody data has been written yet */
> +		if (offset < msgbody_len) {
> +			this_chunk = min(msgbody_len - offset,
>  					 MAX_PRINT_CHUNK - this_header);
>  			if (WARN_ON_ONCE(this_chunk <= 0))
>  				return;
> -			memcpy(buf + this_header, body + offset, this_chunk);
> +			memcpy(buf + this_header, msgbody + offset, this_chunk);
>  			this_offset += this_chunk;
>  		}
> -		/* Body is fully written and there is pending userdata to write,
> -		 * append userdata in this chunk
> +
> +		if (offset + this_offset >= msgbody_len)
> +			/* msgbody was finally written, either in the previous
> +			 * messages and/or in the current buf. Time to write
> +			 * the userdata.
> +			 */
> +			msgbody_written = true;

Something went a bit wrong somewhere, msgbody_written isn't declared
in this scope.

> +
> +		/* Msg body is fully written and there is pending userdata to
> +		 * write, append userdata in this chunk
>  		 */
> -		if (offset + this_offset >= body_len &&
> -		    offset + this_offset < userdata_len + body_len) {
> -			int sent_userdata = (offset + this_offset) - body_len;
> +		if (offset + this_offset >= msgbody_len &&
> +		    offset + this_offset < userdata_len + msgbody_len) {
> +			int sent_userdata = (offset + this_offset) - msgbody_len;
>  			int preceding_bytes = this_chunk + this_header;
>  
>  			if (WARN_ON_ONCE(sent_userdata < 0))
diff mbox series

Patch

diff --git a/drivers/net/netconsole.c b/drivers/net/netconsole.c
index 8faea9422ea1..c312ad6d5cf8 100644
--- a/drivers/net/netconsole.c
+++ b/drivers/net/netconsole.c
@@ -1092,22 +1092,22 @@  static void send_msg_fragmented(struct netconsole_target *nt,
 {
 	static char buf[MAX_PRINT_CHUNK]; /* protected by target_list_lock */
 	int offset = 0, userdata_len = 0;
-	const char *header, *body;
-	int header_len, body_len;
+	const char *header, *msgbody;
+	int header_len, msgbody_len;
 	const char *release;
 
 	if (userdata)
 		userdata_len = nt->userdata_length;
 
 	/* need to insert extra header fields, detect header and body */
 	header = msg;
-	body = memchr(msg, ';', msg_len);
-	if (WARN_ON_ONCE(!body))
+	msgbody = memchr(msg, ';', msg_len);
+	if (WARN_ON_ONCE(!msgbody))
 		return;
 
-	header_len = body - header;
-	body_len = msg_len - header_len - 1;
-	body++;
+	header_len = msgbody - header;
+	msgbody_len = msg_len - header_len - 1;
+	msgbody++;
 
 	/*
 	 * Transfer multiple chunks with the following extra header.
@@ -1122,10 +1122,10 @@  static void send_msg_fragmented(struct netconsole_target *nt,
 	memcpy(buf + release_len, header, header_len);
 	header_len += release_len;
 
 	/* for now on, the header will be persisted, and the body
 	 * will be replaced
 	 */
-	while (offset < body_len + userdata_len) {
+	while (offset < msgbody_len + userdata_len) {
 		int this_header = header_len;
 		int this_offset = 0;
 		int this_chunk = 0;
@@ -1133,23 +1133,31 @@  static void send_msg_fragmented(struct netconsole_target *nt,
 		this_header += scnprintf(buf + this_header,
 					 sizeof(buf) - this_header,
 					 ",ncfrag=%d/%d;", offset,
-					 body_len + userdata_len);
+					 msgbody_len + userdata_len);
 
-		/* Not all body data has been written yet */
-		if (offset < body_len) {
-			this_chunk = min(body_len - offset,
+		/* Not all msgbody data has been written yet */
+		if (offset < msgbody_len) {
+			this_chunk = min(msgbody_len - offset,
 					 MAX_PRINT_CHUNK - this_header);
 			if (WARN_ON_ONCE(this_chunk <= 0))
 				return;
-			memcpy(buf + this_header, body + offset, this_chunk);
+			memcpy(buf + this_header, msgbody + offset, this_chunk);
 			this_offset += this_chunk;
 		}
-		/* Body is fully written and there is pending userdata to write,
-		 * append userdata in this chunk
+
+		if (offset + this_offset >= msgbody_len)
+			/* msgbody was finally written, either in the previous
+			 * messages and/or in the current buf. Time to write
+			 * the userdata.
+			 */
+			msgbody_written = true;
+
+		/* Msg body is fully written and there is pending userdata to
+		 * write, append userdata in this chunk
 		 */
-		if (offset + this_offset >= body_len &&
-		    offset + this_offset < userdata_len + body_len) {
-			int sent_userdata = (offset + this_offset) - body_len;
+		if (offset + this_offset >= msgbody_len &&
+		    offset + this_offset < userdata_len + msgbody_len) {
+			int sent_userdata = (offset + this_offset) - msgbody_len;
 			int preceding_bytes = this_chunk + this_header;
 
 			if (WARN_ON_ONCE(sent_userdata < 0))
@@ -1092,22 +1092,22 @@  static void send_msg_fragmented(struct netconsole_target *nt,
 		userdata_len = nt->userdata_length;
 
-	/* need to insert extra header fields, detect header and body */
+	/* need to insert extra header fields, detect header and msgbody */
 	header = msg;
@@ -1122,10 +1122,10 @@  static void send_msg_fragmented(struct netconsole_target *nt,
 	header_len += release_len;
 
-	/* for now on, the header will be persisted, and the body
+	/* for now on, the header will be persisted, and the msgbody
 	 * will be replaced
 	 */